package Acme::Lou::Effect;
use strict;
use utf8;

our @html_style = (
'<FONT color=#000000 size=4>%s</FONT>',
'<FONT color=#000000>%s</FONT>',
'<FONT color=#0000cc size=5>%s</FONT>',
'<FONT color=#0000cc size=7>%s</FONT>',
'<FONT color=#0000cc>%s</FONT>',
'<FONT color=#0000ff size=4>%s</FONT>',
'<FONT color=#0000ff size=5><STRONG>%s</STRONG></FONT>',
'<FONT color=#0000ff>%s</FONT>',
'<FONT color=#0000ff><STRONG>%s</STRONG></FONT>',
'<FONT color=#003399 size=5>%s</FONT>',
'<FONT color=#003399>%s</FONT>',
'<FONT color=#00683e size=4><STRONG>%s</STRONG></FONT>',
'<FONT color=#00683e size=5>%s</FONT>',
'<FONT color=#00683e>%s</FONT>',
'<FONT color=#00683e><STRONG>%s</STRONG></FONT>',
'<FONT color=#009f62 size=5>%s</FONT>',
'<FONT color=#009f62><STRONG>%s</STRONG></FONT>',
'<FONT color=#4352c2 size=6>%s</FONT>',
'<FONT color=#4352c2>%s</FONT>',
'<FONT color=#666666 size=5>%s</FONT>',
'<FONT color=#666666>%s</FONT>',
'<FONT color=#6a4f9a>%s</FONT>',
'<FONT color=#800080 size=5>%s</FONT>',
'<FONT color=#800080>%s</FONT>',
'<FONT color=#92007b size=4>%s</FONT>',
'<FONT color=#92007b size=5>%s</FONT>',
'<FONT color=#92007b size=6>%s</FONT>',
'<FONT color=#92007b>%s</FONT>',
'<FONT color=#92007b><STRONG>%s</STRONG></FONT>',
'<FONT color=#990033 size=5>%s</FONT>',
'<FONT color=#df0029 size=4>%s</FONT>',
'<FONT color=#df0029 size=4><STRONG>%s</STRONG></FONT>',
'<FONT color=#df0029 size=5>%s</FONT>',
'<FONT color=#df0029 size=5><EM>%s</EM></FONT>',
'<FONT color=#df0029 size=6>%s</FONT>',
'<FONT color=#df0029 size=7>%s</FONT>',
'<FONT color=#df0029>%s</FONT>',
'<FONT color=#df0029><STRONG>%s</STRONG></FONT>',
'<FONT color=#e2007f size=4>%s</FONT>',
'<FONT color=#e2007f size=4><STRONG>%s</STRONG></FONT>',
'<FONT color=#e2007f size=5>%s</FONT>',
'<FONT color=#e2007f size=6>%s</FONT>',
'<FONT color=#e2007f size=6><EM>%s</EM></FONT>',
'<FONT color=#e2007f>%s</FONT>',
'<FONT color=#e2007f><STRONG>%s</STRONG></FONT>',
'<FONT color=#e69c00 size=4>%s</FONT>',
'<FONT color=#e69c00 size=5>%s</FONT>',
'<FONT color=#e69c00>%s</FONT>',
'<FONT color=#e7651a size=4>%s</FONT>',
'<FONT color=#e7651a size=4><STRONG>%s</STRONG></FONT>',
'<FONT color=#e7651a size=5>%s</FONT>',
'<FONT color=#e7651a size=5>%s</FONT>',
'<FONT color=#e7651a size=5><EM>%s</EM></FONT>',
'<FONT color=#e7651a size=5><STRONG>%s</STRONG></FONT>',
'<FONT color=#e7651a size=6>%s</FONT>',
'<FONT color=#e7651a>%s</FONT>',
'<FONT color=#e7651a><STRONG>%s</STRONG></FONT>',
'<FONT face=魚石行書 color=#990033>%s</FONT>',
'<FONT face=魚石行書 size=5>%s</FONT>',
'<FONT face=HG正楷書体-PRO color=#00683e size=4>%s</FONT>',
'<FONT face=HG正楷書体-PRO color=#df0029 size=5>%s</FONT>',
'<FONT face=HG創英角ﾎﾟｯﾌﾟ体 color=#df0029 size=5>%s</FONT>',
'<FONT face=HGP創英角ﾎﾟｯﾌﾟ体 color=#666666>%s</FONT>',
'<FONT face=HGP創英角ﾎﾟｯﾌﾟ体 color=#0000ff size=5>%s</FONT>',
'<FONT face=HGP創英角ﾎﾟｯﾌﾟ体 color=#92007b size=5><EM>%s</EM></FONT>',
'<FONT face=HGP創英角ﾎﾟｯﾌﾟ体 size=5>%s</FONT>',
'<FONT face=HGP創英角ﾎﾟｯﾌﾟ体 size=6 color=#009F62>%s</FONT>',
'<FONT face=HGP創英角ﾎﾟｯﾌﾟ体 size=6 color=#666666>%s</FONT>',
'<FONT face=HGP創英角ﾎﾟｯﾌﾟ体>%s</FONT>',
'<FONT face=HGS創英角ﾎﾟｯﾌﾟ体 size=5>%s</FONT>',
'<FONT face=HGS創英角ﾎﾟｯﾌﾟ体 color="#e2007f" size="4">%s</FONT>',
'<FONT face=HGS創英角ﾎﾟｯﾌﾟ体>%s</FONT>',
'<FONT size=2>%s</FONT>',
'<FONT size=3>%s</FONT>',
'<FONT size=4 color=#4352c2><STRONG>%s</STRONG></FONT>',
'<FONT size=5 color=#800080>%s</FONT>',
'<FONT size=5 color=#e2007f><EM><STRONG>%s</STRONG></EM></FONT>',
'<FONT size=5 color=#e2007f><STRONG><EM>%s</EM></STRONG></FONT>',
'<FONT size=6>%s</FONT>',
'<FONT size=7>%s</FONT>',
'<FONT style="BACKGROUND-COLOR: #bcdfff">%s</FONT>',
);

sub html_fx {
    sprintf $html_style[ int rand @html_style ], shift || "";
}

1;
